---
title: KG이니시스 상점아이디 추가 절차
category: 결제서비스 (채널설정 및 이용안내) > 이용안내 > 서비스 추가/변경
seo:
  title: KG이니시스 상점아이디 추가 절차
  description: >-
    KG이니시스의 상점아이디(사이트코드) 추가절차 안내입니다. 추가 상점아이디는 포트원 호스팅사를 기준으로 수수료가 적용되며, 상점아이디를
    추가하실 수 있는 경우를 확인하세요.
  keywords:
    - KG이니시스
    - 서비스추가/변경
tags:
  - KG이니시스
  - 서비스추가/변경
pgCompanies:
  - KG이니시스
searchTags:
  - KG이니시스 MID
  - KG이니니스 상점아이디
  - KG이니시스 서비스 추가
  - KG이니시스 상점아이디 추가
  - 사이트추가
  - 사이트 추가
  - 서비스 추가
  - MID 추가
  - 상점아이디추가
datetime: 2024-02-15T15:00:00.000Z
---

<Callout content="KG이니시스 상점아이디 추가 절차를 안내해드립니다. 
추가되는 상점아이디는 포트원 호스팅사를 기준으로 수수료가 적용되는 점 참고해주세요." />

<Callout title="포트원 기준 결제대행사 수수료 보러가기↗" />

### **상점아이디 추가 케이스**

<Callout content="포트원 정책에 의하여 기존에 포트원을 통하지 않고 계약된 상점아이디는 포트원 서비스 사용이 불가합니다. 새로운 포트원용 상점아이디를 추가 발급 받으신 후 이용해주시기 바랍니다." title="참고사항" icon="💡" />

- 이미 KG이니시스와 직접 계약이 되어있다가 포트원으로 연동하고자 하시는 경우
- 다른 호스팅사를 통해 KG이니시스와 계약 되어있다가 포트원으로 연동하시는 경우
- 새로운 서비스가 추가되는 경우 (=심사를 다시 받아야 하는 경우)
- 기존 서비스와 결제/정산을 분리하고자 하시는 경우
- 심사받은 적 없는 연동방식을 추가하시는 경우 (ex. 일반결제 사용중에 정기결제 추가시)

### **신청방법**

#### **신청 경로**

[KG이니시스 관리자페이지↗](https://iniweb.inicis.com/security/login.do) 접속 > **기존** KG이니시스 상점아이디로 로그인 > 변경/추가 > 정보변경 및 서비스추가 >1. 서비스 추가 및 변경 > 1.3 MID추가 > 1.3.1 MID추가 및 변경



#### **작성 내용**



- 그외 호스팅 ID : 체크
- URL : 포트원을 통해 연동하실 사이트URL (혹은 앱스토어URL) 기재
- 호스팅 정보 : "(주)포트원" 기재
- 서비스 선택 : 추가되는 MID에 적용할 결제수단 체크
- 지급 계좌 선택 : 기존 지급 계좌와 동일한 경우 체크
  (별도 계좌로 정산받기를 희망하는 경우 계좌변경 정보 기재 후 \[계좌조회] 클릭)

<Callout content=" 신청하시는 사이트에 상품 및 사업자정보 노출 적용등 기본 구성이 되어있다면
**익 영업일이내** 발급되며, 이니시스 내부 사정에 따라 지연될 수 있는 점 참고바랍니다." icon="💡" title="참고사항" />

### 결제수단 추가

#### **신청 경로**

[KG이니시스 관리자페이지↗](https://iniweb.inicis.com/security/login.do) 접속 > **기존** KG이니시스 상점아이디로 로그인 > 변경/추가 > 1.2.1 지불수단 추가 및 변경 > 원하는 결제수단 선택 후 신청하기



### **정기결제 특약 신청**

정기결제 이용시에는 추가된 상점아이디에 정기결제 특약서비스를 추가신청 해주셔야 합니다.

#### **신청 경로**

[KG이니시스 관리자 페이지↗](https://iniweb.inicis.com/security/login.do)  KG이니시스 상점아이디로 로그인 > 변경/추가 > 정보변경 및 서비스추가 > 1.서비스 추가 및 변경 > 1.2 지불수단 추가 및 변경 > 1.2.3 특약 서비스 추가



#### **작성 내용**



- 자동결제 빌링 : 선택
- 약관확인 및 동의 : 체크
- 자동결제 빌링 사용 : 체크
- 대표사업장 신용카드 자동결제 사용 : 체크 (신용카드 지불수단만 지원가능)

<Callout icon="❗" title="유의사항" content="MID가 추가발급되면 키파일 이라는 압축파일을 전달받습니다.
키파일은 일반결제용 · 정기결제용을 구분하여 cs@portone.io으로 반드시 보내주시기 바라며,
포트원에서 등록되지 않은 키파일의 경우 일부 결제 · 환불이 실패할 수 있습니다. 
(오류메세지 : TX9301|상점개인키 로드오류)" />
